@@ -13,6 +13,8 @@ test_that("Golem Bare", {
   expect_output(scaffold_golem(edit = FALSE))
   expect_message(bundle_dev())
   expect_message(add_plugin_html(use_pug = TRUE))
+  expect_message(add_plugin_prettier())
+  expect_message(add_plugin_eslint())
   setwd(wd)
   delete_tmp_package(pkg)
 })
@@ -50,6 +52,10 @@ test_that("Golem no CDN", {
   pkg <- create_tmp_golem()
   setwd(pkg)
   expect_output(scaffold_golem(react = TRUE, use_cdn = FALSE, edit = FALSE))
+  expect_error(add_test_file())
+  expect_error(add_test_file('sth'))
+  expect_message(include_tests())
+  add_test_file('sth')
   expect_message(bundle())
   setwd(wd)
   delete_tmp_package(pkg)
